@@ -110,21 +110,6 @@ class Api(Utils):
             plural_name = self.name + 's'
         return plural_name
 
-    @property
-    def urls(self):
-        return [
-            url(
-                  r'^%s/$' % self.plural_name
-                , self.all
-                , name=self.plural_name
-            ),
-            url(
-                  r'^%s/(?P<pk>\d+)/$' % self.plural_name
-                , self.one
-                , name=self.name
-            ),
-        ]
-
     @property
     def field_list(self):
         for field_name in self.fields:
@@ -165,11 +150,10 @@ class Api(Utils):
     @property
     def relations(self):
         for item in self.model._meta.get_all_related_objects():
-            yield Relation(item)
+            if type(item.field) == ForeignKey:
+                yield Relation(item)
 
-    #
     # update `item` with `req`.body
-    #
     def __update__(self, req, item):
 
         try:
@@ -190,6 +174,22 @@ class Api(Utils):
             if value:
                 setattr(item, field.name, value)
 
+
+    @property
+    def urls(self):
+        return [
+            url(
+                  r'^%s/$' % self.plural_name
+                , self.all
+                , name=self.plural_name
+            ),
+            url(
+                  r'^%s/(?P<pk>\d+)/$' % self.plural_name
+                , self.one
+                , name=self.name
+            ),
+        ]
+
     # GET /`model`/
     @csrf_exempt
     def all(self, req):
